# `autopew`

<p align="left">
<a href="https://autopew.readthedocs.io/">
   <img src="https://readthedocs.org/projects/autopew/badge/?version=develop" alt="Docs"/></a>

<a href="https://github.com/morganjwilliams/autopew/blob/master/LICENSE" >
  <img src="https://img.shields.io/badge/License-CSIRO_BSD/MIT_License-blue.svg"
       alt="License: CSIRO Modified BSD/MIT License"></a>
<a href="https://gitter.im/pyrolite/autopew" >
 <img src="https://img.shields.io/gitter/room/pyrolite/autopew.svg"
      alt="Chat on Gitter"></a>
</p>

Automating sample targeting for geological microanalysis systems.

## Install

[![PyPI](https://img.shields.io/pypi/v/autopew.svg?style=flat)](https://pypi.python.org/pypi/autopew)
[![Compatible Python Versions](https://img.shields.io/pypi/pyversions/autopew.svg?style=flat)](https://pypi.python.org/pypi/autopew/)
[![autopew downloads](https://img.shields.io/pypi/dm/autopew.svg?style=flat)](https://pypistats.org/packages/autopew)

```bash
pip install autopew
```

If you want the most up to date *development* version, you can instead install directly from the GitHub repo. Note that breaking changes occur on this branch, and is not guaranteed to remain stable (check the [Development and Build Status](#development--build-status) below). If you still want to try out the most recent bugfixes and yet-to-be-released features, you can install this version with:

```bash
pip install git+git://github.com/morganjwilliams/autopew.git@develop#egg=autopew
```

For more information, see the documentation's
[installation page](https://autopew.readthedocs.io/en/develop/installation.html), and
the [Getting Started Guide](https://autopew.readthedocs.io/en/develop/usage/gettingstarted.html).


## Development & Build Status
<p align='left'>
  <a href="https://github.com/python/black">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg"
         alt="Code Style: Black"></a>
</p>


|                                                                                                 **master**                                                                                                 |                                                                                                  **develop**                                                                                                  |
|:----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------:|:-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------:|
| [![Unit Tests on Master](https://github.com/morganjwilliams/autopew/workflows/Unittest/badge.svg?branch=master)](https://github.com/morganjwilliams/autopew/actions?query=workflow:Unittest+branch:master) | [![Unit Tests on Develop](https://github.com/morganjwilliams/autopew/workflows/Unittest/badge.svg?branch=develop)](https://github.com/morganjwilliams/autopew/actions?query=workflow:Unittest+branch:develop) |
|                 [![Coverage Status](https://coveralls.io/repos/github/morganjwilliams/autopew/badge.svg?branch=master)](https://coveralls.io/github/morganjwilliams/autopew?branch=master)                 |                 [![Coverage Status](https://coveralls.io/repos/github/morganjwilliams/autopew/badge.svg?branch=develop)](https://coveralls.io/github/morganjwilliams/autopew?branch=develop)                  |
